@@ -3,7 +3,6 @@ from .recycle import *
 
 from .ffsync import ffsync
 from .ffconcat import ffconcat
-from .lazytrim import lazytrim
 from .improve_dlc_output import improve_dlc_output
 from .improve_dlc_csv import improve_dlc_csv
 from .improve_dlc_output_cat_alone import improve_dlc_output_cat_alone
@@ -18,9 +17,11 @@ from .calc_dlc_mw import calc_dlc_mw
 from .dlcboxplot import dlcboxplot
 from .turning_points import turning_points_output
 from .improve_turnpoints import improve_turnpoints
-from .std_cols import std_cols
 from .turnpoints_time_diff import turnpoints_time_diff
 from .find_tps_velocity_values import find_tps_velocity_values
 from .fwarnings import fwarnings
+from .one_cat_one_file import one_cat_one_file
+from .correct_times import correct_times
+from .create_time_diff_data import create_time_diff_data
 
 from .version import __version__, VERSION
