@@ -10,7 +10,14 @@ import seaborn as sns
 import matplotlib.pyplot as plt
 
 
-def dlcboxplot(file, variable, ylab, jitter=False, colors=False, title=False, save=False, output_dir=False):
+def dlcboxplot(file,
+               variable,
+               ylab,
+               jitter=False,
+               colors=False,
+               title=False,
+               save=False,
+               output_dir=False):
 
     df = pd.read_csv(file)
     df = df[df['var'] == variable]
@@ -24,22 +31,36 @@ def dlcboxplot(file, variable, ylab, jitter=False, colors=False, title=False, sa
     else:
         my_pal = {"Negative": colors[0], "Positive": colors[1]}
 
-    ax = sns.boxplot(x='trial', y='value', data=df,
-                     hue='status', palette=my_pal)
+    ax = sns.boxplot(x='trial',
+                     y='value',
+                     data=df,
+                     hue='status',
+                     palette=my_pal)
 
     if jitter is True:
 
-        sns.stripplot(x='trial', y='value', data=df,
-                      color='black', size=3, jitter=1)
-
+        sns.stripplot(x='trial',
+                      y='value',
+                      data=df,
+                      color='black',
+                      size=3,
+                      jitter=1)
     '''add vertical lines to seperate boxplots pairs (style)'''
-    for i in range(len(df['trial'].unique())-1):
+    for i in range(len(df['trial'].unique()) - 1):
         if variable == 'vel':
-            plt.vlines(i+.5, 10, 45, linestyles='solid',
-                       colors='black', alpha=0.2)
+            plt.vlines(i + .5,
+                       10,
+                       45,
+                       linestyles='solid',
+                       colors='black',
+                       alpha=0.2)
         elif variable == 'cat_distance':
-            plt.vlines(i+.5, 0, 1.3, linestyles='solid',
-                       colors='black', alpha=0.2)
+            plt.vlines(i + .5,
+                       0,
+                       1.3,
+                       linestyles='solid',
+                       colors='black',
+                       alpha=0.2)
 
     if title is not False:
         plt.title(title, fontsize=14)
@@ -49,7 +70,6 @@ def dlcboxplot(file, variable, ylab, jitter=False, colors=False, title=False, sa
     ax.set(xlabel='Trial', ylabel=ylab)
 
     plt.legend(title='Infection Status')
-
     '''add significance bars and asterisks between boxes'''
     # [first pair, second pair], ..., [|, –], ...
     if variable == 'vel':
@@ -59,8 +79,9 @@ def dlcboxplot(file, variable, ylab, jitter=False, colors=False, title=False, sa
 
     for x1, x2, y1, y2 in zip(l[0], l[1], l[2], l[3]):
         sig = plt.plot([x1, x1, x2, x2], [y1, y2, y2, y1],
-                       linewidth=1, color='k')
-        plt.text((x1+x2)*.5, y2+0, "*", ha='center', va='bottom')
+                       linewidth=1,
+                       color='k')
+        plt.text((x1 + x2) * .5, y2 + 0, "*", ha='center', va='bottom')
 
     plt.show()
 
@@ -68,7 +89,11 @@ def dlcboxplot(file, variable, ylab, jitter=False, colors=False, title=False, sa
         fig = ax.get_figure()
         if output_dir is not False:
             fig.savefig(f'{output_dir}/{variable}.png',
-                        bbox_inches="tight", dpi=100, pad_inches=0.1)
+                        bbox_inches="tight",
+                        dpi=100,
+                        pad_inches=0.1)
         else:
-            fig.savefig(f'{variable}.png', bbox_inches="tight",
-                        dpi=100, pad_inches=0.1)
+            fig.savefig(f'{variable}.png',
+                        bbox_inches="tight",
+                        dpi=100,
+                        pad_inches=0.1)
